import request from "@/utils/request";
import { encrypt } from "@/utils/jsencrypt";
import { AxiosPromise } from "axios";
import { CaptchaResult, LoginData, GetBwCaptcha } from "./types";

import Qs from "qs";
/**
 * 登录API
 *
 * @param data {LoginData}
 * @returns
 */
export function loginApi({
  username,
  password,
  code,
  uuid,
}: LoginData): AxiosPromise<string> {
  const params = {
    username,
    password,
    code,
    uuid,
  };
  return request({
    url: "/auth/login",
    method: "post",
    data: Qs.stringify({
      sign: encrypt(params),
    }),
    headers: {},
  });
}

/**
 * 注销API
 */
export function logoutApi() {
  return request({
    url: "/logout",
    method: "post",
  });
}

/**
 * 获取验证码
 */
export function captchaImage(): AxiosPromise<CaptchaResult> {
  return request({
    url: "/captcha/captchaImage",
    method: "get",
  });
}

// 获取验证图片
export function getBwCaptcha(params: GetBwCaptcha) {
  const data = Qs.stringify(params);
  return request({
    url: "/captcha/getBwCaptcha",
    method: "post",
    data,
  });
}

// 滑动或者点选验证
export function checkBwCaptcha(params: any) {
  const data = Qs.stringify(params);
  return request({
    url: "/captcha/checkBwCaptcha",
    method: "post",
    data,
  });
}
