import request from "@/utils/request";
import { AxiosPromise } from "axios";
import { DeptForm, DeptQuery, DeptVO } from "./types";
import Qs from "qs";

/**
 * 部门下拉列表
 */
export function getDeptOptions(): AxiosPromise<OptionType[]> {
  return request({
    url: "/system/dept/treeSelect",
    method: "get",
  });
}

/**
 * 1.新增部门
 * 2.删除部门
 * 3.修改部门
 * 4.修改部门状态
 * 5.查询部门列表
 * 6.查询部门列表（排除节点）
 * 7.查询部门详细
 * -----------------
 * 10.查询部门下拉树结构
 * 11.查询子部门
 * 12.根据角色ID查询部门树结构
 * 13.查询无部门人员
 * 14.根据查询内容查询用户
 * 15.查询该部门下的所有用户
 * 16.转部门
 * */

// 1.新增部门
export function addDept(data: any) {
  data = Qs.stringify(data);
  return request({
    url: "/system/dept/add",
    method: "post",
    data,
    headers: {},
  });
}

// 2.删除部门
export function delDept(deptId: any) {
  return request({
    url: "/system/dept/deleteLogical/" + deptId,
    method: "delete",
  });
}

// 3.修改部门
export function updateDept(data: any) {
  const businessId = data.businessId;
  data = Qs.stringify(data);
  return request({
    url: "/system/dept/update/" + businessId,
    method: "put",
    data,
    headers: {},
  });
}

// 4.修改部门状态
export function statusChange(data: any) {
  const businessId = data.businessId;
  data = Qs.stringify(data);
  return request({
    url: "/system/dept/statusChange/" + businessId,
    method: "put",
    data,
    headers: {},
  });
}

// 5.查询部门列表
export function listDept(query: any) {
  return request({
    url: "/system/dept/list",
    method: "get",
    params: query,
  });
}

// 6.查询部门列表（排除节点）
export function listDeptExcludeChild(deptId: any) {
  return request({
    url: "/system/dept/list/exclude/" + deptId,
    method: "get",
  });
}

// 7.查询部门详细
export function getDept(deptId: any) {
  return request({
    url: "/system/dept/detail/" + deptId,
    method: "get",
  });
}

// 10.查询部门下拉树结构
export function treeSelect() {
  return request({
    url: "/system/dept/treeSelect",
    method: "get",
  });
}

// 11.查询子部门
export function getChildrenDept(userId: any) {
  return request({
    url: "/system/dept/getChildren/" + userId,
    method: "get",
  });
}

// 12.根据角色ID查询部门树结构
export function roleDeptTreeSelect(roleId: any, menuId: any) {
  return request({
    url: "/system/dept/roleDeptTreeSelect/" + roleId + "/" + menuId,
    method: "get",
  });
}

// 13.查询无部门人员
export function queryUserWithoutDept(params: any) {
  return request({
    url: "/system/dept/getAllUserWithoutDept",
    method: "get",
    params,
  });
}

// 14.根据查询内容查询用户
export function queryUserByName(params: any) {
  return request({
    url: "/system/user/getListWithDept",
    method: "get",
    params,
  });
}

// 15.查询该部门下的所有用户
export function queryUserByDeptId(id: any, params: any) {
  return request({
    url: "/system/dept/getAllUserByDeptId/" + id,
    method: "get",
    params,
  });
}

// 16.转部门
export function transformDept(data: any) {
  return request({
    url: "/system/dept/update/{businessId}",
    method: "put",
    data,
  });
}
