/**
 * 字典类型查询参数
 */
export interface DictTypeQuery extends PageQuery {
  /**
   * 字典名称
   */
  dictName?: string;
  /**
   * 字典类型
   */
  dictType?: string;
  /**
   * 状态
   */
  flag?: string;
  /**
   * 开始时间
   */
  beginTime?: string | null;
  /**
   * 结束时间
   */
  endTime?: string | null;
}

/**
 * 字典数据查询参数
 */
export interface DictTypeDataQuery extends PageQuery {
  /**
   * 字典名称
   */
  dictType?: string;
  /**
   * 字典标签
   */
  dictLabel?: string;
  /**
   * 状态
   */
  flag?: string;
}

/**
 * 字典类型分页对象
 */
export interface DictTypePageVO {
  /**
   * 字典类型ID
   */
  businessId: number;
  /**
   * 字典名称
   */
  dictName: string;
  /**
   * 字典类型
   */
  dictType: string;
  /**
   * 状态
   */
  flag: string;
  /**
   * 备注
   */
  remarks: string;
  /**
   * 创建时间
   */
  createDate: Date;
}
/**
 * 字典类型数据分页对象
 */
export interface DictTypeDataPageVO {
  /**
   * 字典编码
   */
  businessId: number;
  /**
   * 字典标签
   */
  dictLabel: string;
  /**
   * 字典键值
   */
  dictValue: string;
  /**
   * 字典排序
   */
  dictSort: string | number;
  /**
   * 状态
   */
  flag: string | number;
  /**
   * 备注
   */
  remarks: string | number;
  /**
   * 创建时间
   */
  createDate: any;
}
/**
 * 字典分页项类型声明
 */
export type DictTypePageResult = PageResult<DictTypePageVO[]>;

/**
 * 字典表单类型声明
 */
export interface DictTypeForm {
  /**
   * 字典类型ID
   */
  businessId?: number | undefined;
  /**
   * 字典名称
   */
  dictName?: string;
  /**
   * 字典类型
   */
  dictType?: string;
  /**
   * 父字典名称
   */
  parentId?: number | undefined;
  /**
   * 父字典数据
   */
  dataId?: number | undefined;
  /**
   * 备注
   */
  remarks?: string;

  status?: string | number;

  flag?: string | number;
}
/**
 * 字典表单类型数据声明
 */
export interface DictTypeDataForm {
  /**
   * 字典类型ID
   */
  businessId?: number | undefined;
  /**
   * 字典类型
   */
  dictType?: number | string;
  /**
   * 参数标签
   */
  dictLabel?: number | string;
  /**
   * 参数键值
   */
  dictValue?: number | string;
  /**
   * 参数排序
   */
  dictSort?: number | string;
  /**
   * 备注
   */
  remarks?: string;
}
/**
 * 字典查询参数
 */
export interface DictQuery extends PageQuery {
  /**
   * 字典项名称
   */
  name?: string;
  /**
   * 字典类型编码
   */
  typeCode?: string;
}

/**
 * 字典分页对象
 */
export interface DictPageVO {
  /**
   * 字典ID
   */
  id?: number;
  /**
   * 字典名称
   */
  name?: string;
  /**
   * 状态(1:启用;0:禁用)
   */
  status?: number;
  /**
   * 字典值
   */
  value?: string;
}

/**
 * 字典分页
 */
export type DictPageResult = PageResult<DictPageVO[]>;

/**
 * 字典表单
 */
export interface DictForm {
  /**
   * 字典ID
   */
  id?: number;
  /**
   * 字典名称
   */
  name?: string;
  /**
   * 排序
   */
  sort?: number;
  /**
   * 状态(1:启用;0:禁用)
   */
  status?: number;
  /**
   * 类型编码
   */
  typeCode?: string;
  /**
   * 值
   */
  value?: string;

  /**
   * 备注
   */
  remark?: string;
}
