import request from "@/utils/request";
import { AxiosPromise } from "axios";
import { User, UserForm, UserInfo, UserPageVO, UserQuery } from "./types";
import { praseStrEmpty } from "@/utils/common";
/**
 * 登录成功后获取用户信息（昵称、头像、权限集合和角色集合）
 */
export function getUserInfoApi() {
  return request({
    url: "/system/user/getInfo",
    method: "get",
  });
}

/**
 * 获取用户分页列表
 *
 * @param queryParams
 */
export function getUserPage(
  queryParams: UserQuery
): AxiosPromise<PageResult<UserPageVO[]>> {
  return request({
    url: "/system/user/list",
    method: "get",
    params: queryParams,
  });
}

/**
 * 获取用户表单详情
 *
 * @param userId
 */
export function getUserForm(userId: number): AxiosPromise<UserForm> {
  return request({
    url: "/system/user/" + praseStrEmpty(userId),
    method: "get",
  });
}

/**
 * 添加用户
 *
 * @param data
 */
export function addUser(data: any) {
  return request({
    url: "/system/user/add",
    method: "post",
    data: data,
  });
}

/**
 * 修改用户
 *
 * @param id
 * @param data
 */
export function updateUser(data: UserForm) {
  return request({
    url: "/system/user/update",
    method: "put",
    data: data,
  });
}

/**
 * 修改用户密码
 *
 * @param id
 * @param password
 */
export function updateUserPassword(businessId: number, password: string) {
  const data = {
    businessId,
    password,
  };
  return request({
    url: "/system/user/resetPassword",
    method: "put",
    params: data,
  });
}
/**
 * 用户状态修改
 *
 */
export function changeUserStatus(businessId: number, flag: string) {
  const data = {
    businessId,
    flag,
  };
  return request({
    url: "/system/user/changeStatus",
    method: "put",
    params: data,
  });
}
/**
 * 删除用户
 *
 * @param ids
 */
export function deleteUsers(id: number) {
  return request({
    url: "/system/user/deleteLogical/" + id,
    method: "delete",
  });
}

/**
 * 下载用户导入模板
 *
 * @returns
 */
export function downloadTemplateApi() {
  return request({
    url: "/system/user/importTemplate",
    method: "get",
    responseType: "arraybuffer",
  });
}

/**
 * 导出用户
 *
 * @param queryParams
 * @returns
 */
export function exportUser(queryParams: UserQuery) {
  return request({
    url: "/system/user/export",
    method: "get",
    params: queryParams,
    responseType: "arraybuffer",
  });
}

/**
 * 导入用户
 *
 * @param file
 */
export function importUser(data: any) {
  return request({
    url: "/system/user/importExcel",
    method: "post",
    headers: {
      "Content-Type": "multipart/form-data",
    },
    transformRequest: [
      (data) => {
        return data;
      },
    ],
    data,
  });
}
