export interface User {
  /**
   * 用户名称
   */
  username?: string;
  /**
   * 用户特殊标志
   */
  specialTag?: string;
  /**
   * 用户头像地址
   */
  avatar?: any;
}

/**
 * 登录用户信息
 */
export interface UserInfo {
  /**
   * 用户id
   */
  userId?: number;
  /**
   * 用户名称
   */
  username?: string;
  /**
   * 用户昵称
   */
  nickname?: string;
  /**
   * 用户头像地址
   */
  avatar?: string;
  /**
   * token
   */
  token: string | null;
  /**
   * 用户角色
   */
  roles: string[];
  /**
   * 用户权限
   */
  permissions: string[];
  /**
   * 用户特殊标志
   */
  specialTag?: string;
  /**
   * 用户数据
   */
  user?: User | undefined;
  menus?: [];
}

/**
 * 用户查询对象类型
 */
export interface UserQuery extends PageQuery {
  /**
   * 部门ID
   */
  deptId?: number | undefined;
  /**
   * 登录名
   */
  username?: string;
  /**
   * 状态
   */
  flag?: string;
}

/**
 * 用户分页对象
 */
export interface UserPageVO {
  /**
   * 用户ID
   */
  businessId?: number;
  /**
   * 登录名
   */
  username?: string;
  /**
   * 姓名
   */
  name?: string;
  /**
   * 手机号
   */
  phone?: string;
  /**
   * 状态
   */
  flag?: string;
  /**
   * 创建时间
   */
  createDate?: Date;
}

/**
 * 用户表单类型
 */
export interface UserForm {
  /**
   * 用户ID
   */
  businessId?: number | undefined;
  /**
   * 登录名
   */
  username?: string;
  /**
   * 密码
   */
  password?: string;
  /**
   * 姓名
   */
  name?: string;
  /**
   * 昵称
   */
  nickName?: string;
  /**
   * 性别
   */
  sex?: string;
  /**
   * 手机号码
   */
  phone?: string;
  /**
   * 身份证号
   */
  idNumber?: string;
  /**
   * 邮箱
   */
  email?: string;
  /**
   * 状态(1:启用;0:停用)
   */
  flag?: string;
  /**
   * 部门ID
   */
  deptId?: number | null;
  /**
   * 角色
   */
  roleList?: number[];
  /**
   * 角色返参字符串
   */
  roleIds?: string;
  /**
   * 备注
   */
  remarks?: string;
}
