import router from "@/router";
import { useUserStoreHook } from "@/store/modules/user";
import { getToken } from "@/utils/auth";

import NProgress from "nprogress";
import "nprogress/nprogress.css";

NProgress.configure({ showSpinner: false }); // 进度条

const userStore = useUserStoreHook();

// 白名单路由
const whiteList = ["/login"];

router.beforeEach(async (to, from, next) => {
  NProgress.start();
  if (getToken()) {
    if (to.path === "/login") {
      // 如果已登录，跳转首页
      next();
      NProgress.done();
    } else {
      const hasRoles = userStore.user.roles && userStore.user.roles.length > 0;
      if (hasRoles) {
        // 未匹配到任何路由，跳转404
        if (to.matched.length === 0) {
          from.name ? next({ name: from.name }) : next("/404");
        } else {
          next();
        }
      } else {
        try {
          const { permissions } = await userStore.getUserInfo();
          if (permissions && permissions.length > 0) {
            const accessRoutes = await userStore.generateRoutes();
            accessRoutes.forEach((route) => {
              router.addRoute(route);
            });
            next({ ...to, replace: true });
          } else {
            userStore.logout().then((_) => {
              alert("用户无权限");
              next(`/login`);
            });
          }
        } catch (error) {
          // 移除 token 并跳转登录页
          await userStore.resetToken();
          next(`/login?redirect=${to.path}`);
          NProgress.done();
        }
      }
    }
  } else {
    // 未登录可以访问白名单页面
    if (whiteList.indexOf(to.path) !== -1) {
      next();
    } else {
      next(`/login?redirect=${to.path}`);
      NProgress.done();
    }
  }
});

router.afterEach(() => {
  NProgress.done();
});
