import moment from "moment/moment";

/**
 * 构造树型结构数据
 * @param {*} data 数据源
 * @param {*} id id字段 默认 'id'
 */
export function handleTree(
  data: any,
  id: any,
  parentId: any,
  children: any,
  rootId: any
) {
  id = id || "id";
  parentId = parentId || "parentId";
  const number = Math.random();
  rootId =
    rootId ||
    Math.min(
      number,
      ...data.map((item: any) => {
        return item[parentId];
      })
    ) ||
    0;
  // 对源数据深度克隆
  const cloneData = JSON.parse(JSON.stringify(data));
  // 循环所有项
  const treeData = cloneData.filter((father: any) => {
    const branchArr = cloneData.filter((child: any) => {
      // 返回每一项的子级数组
      return father[id] === child[parentId];
    });
    branchArr.length > 0 ? (father.children = branchArr) : "";
    // 返回第一层
    return father[parentId] === rootId;
  });
  return treeData !== "" ? treeData : data;
}
// 转换字符串，undefined,null等转化为""
export function praseStrEmpty(str: any) {
  if (!str || str === "undefined" || str === "null") {
    return "";
  }
  return str;
}

export function transformDateByFormat(value: any, format: any) {
  if (!value || value === "") {
    return "-";
  }
  return moment(value).format(format || "YYYY-MM-DD HH:mm:ss");
}

export function addDateRange(params: any, dateRange: any) {
  const search = params;
  search.beginTime = "";
  search.endTime = "";
  if (dateRange != null && dateRange !== "") {
    search.beginTime = dateRange[0];
    search.endTime = dateRange[1];
  }
  return search;
}
export function parseTime(time: any, pattern: any) {
  if (arguments.length === 0 || !time) {
    return null;
  }
  const format = pattern || "{y}-{m}-{d} {h}:{i}:{s}";
  let date;
  if (typeof time === "object") {
    date = time;
  } else {
    if (typeof time === "string" && /^[0-9]+$/.test(time)) {
      time = parseInt(time);
    } else if (typeof time === "string") {
      time = time.replace(new RegExp(/-/gm), "/");
    }
    if (typeof time === "number" && time.toString().length === 10) {
      time = time * 1000;
    }
    date = new Date(time);
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay(),
  };
  const time_str = format.replace(
    /{(y|m|d|h|i|s|a)+}/g,
    (result: any, key: any) => {
      let value = formatObj[key];
      // Note: getDay() returns 0 on Sunday
      if (key === "a") {
        return ["日", "一", "二", "三", "四", "五", "六"][value];
      }
      if (result.length > 0 && value < 10) {
        value = "0" + value;
      }
      return value || 0;
    }
  );
  return time_str;
}
