import axios, { InternalAxiosRequestConfig, AxiosResponse } from "axios";
import { useUserStoreHook } from "@/store/modules/user";
import { getToken, setToken } from "@/utils/auth";
import { errorCode } from "@/utils/errorCode";
import { ElMessage } from "element-plus";

// 创建 axios 实例
axios.defaults.headers["Content-Type"] = "application/x-www-form-urlencoded";
const service = axios.create({
  baseURL: import.meta.env.VITE_APP_BASE_API,
  timeout: 100000,
  // headers: { "Content-Type": "application/json;charset=utf-8" },
});

// 请求拦截器
service.interceptors.request.use(
  (config: InternalAxiosRequestConfig) => {
    const isToken = (config.headers || {}).isToken === false;
    if (getToken() && !isToken) {
      config.headers["Authorization"] = "Bearer " + getToken(); // 让每个请求携带自定义token 请根据实际情况自行修改
    }
    return config;
  },
  (error: any) => {
    return Promise.reject(error);
  }
);

interface a {
  code: string;
}
// 响应拦截器
service.interceptors.response.use(
  (res: AxiosResponse) => {
    // 未设置状态码则默认成功状态
    const code: number = res.data.code || 200;
    // 获取错误信息
    const message: string =
      errorCode[code] ||
      res.data.msg ||
      res.data.message ||
      errorCode["default"];
    // status为401 code为e004则重新获取token
    if (code === 401) {
      ElMessage({
        message: "用户不存在或密码错误",
        type: "error",
      });
    } else if (code === 500 || code === 400) {
      const errMsg = res.data.data || res.data.message || res.data.msg;
      ElMessage({
        message: errMsg,
        type: "error",
      });
      return Promise.reject(new Error(message));
    } else if (code !== 200) {
      ElMessage({
        message: message,
        type: "error",
        duration: 5 * 1000,
      });
      return Promise.reject("error");
    } else {
      if (res.data instanceof ArrayBuffer) {
        return res;
      } else {
        return res.data;
      }
    }
  },
  (error: any) => {
    ElMessage({
      message: error.message,
      type: "error",
      duration: 5 * 1000,
    });
    return Promise.reject(error);
  }
);

// 导出 axios 实例
export default service;
